@@ -1,7 +1,7 @@
-from turengcli.cli import TurengDict
+from .cli import TurengDict
 import argparse
 
-__version__ = "0.0.1"
+__version__ = "0.0.3"
 
 # parse arguments
 ap = argparse.ArgumentParser()
@@ -11,6 +11,20 @@ ap.add_argument(
     nargs="*",
     help="<word>",
 )
+ap.add_argument(
+    "-c",
+    "--correct",
+    action="store_true",
+    default=False,
+    help="auto-correct misspelled input with first suggestion",
+)
+ap.add_argument(
+    "-d",
+    "--detailed",
+    action="store_true",
+    default=False,
+    help="detailed results",
+)
 ap.add_argument(
     "-p",
     "--plain",
@@ -30,7 +44,7 @@ args = ap.parse_args()
 
 
 def cli():
-    word = "".join(args.word)
+    word = " ".join(args.word)
     print("Please enter a word.") if word == "" else TurengDict(word, args)
 
 
